#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-conversions
version:              0.3.1.1
visibility:           public
id:                   text-conversions-0.3.1.1-CsFwKQTdrkY5HgNyNTZjRW
key:                  text-conversions-0.3.1.1-CsFwKQTdrkY5HgNyNTZjRW
license:              ISC
maintainer:           Alexis King <lexi.lambda@gmail.com>
author:               Alexis King
homepage:             https://github.com/cjdev/text-conversions
synopsis:             Safe conversions between textual types
description:          Safe conversions between textual types
category:             Data
abi:                  ac07d91c1ea964c3a9ad1b9b0e05bf83
exposed:              True
exposed-modules:      Data.Text.Conversions
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-conversions-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-conversions
hs-libraries:         HStext-conversions-0.3.1.1-CsFwKQTdrkY5HgNyNTZjRW
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-DtNKPfG3uwoHKAxlYu0flv
    base64-bytestring-1.2.1.0-5FCrsQJfd7YEO3ux55GN8R
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-text-conversions/html/text-conversions.haddock

haddock-html:         /usr/share/doc/haskell-text-conversions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

